@@ -3,7 +3,7 @@
 
 # JACK-Capture frontend, with freewheel and transport support
 # Copyright (C) 2010-2018 Filipe Coelho <falktx@falktx.com>
-# Copyright (C) 2020-2021 Christopher Arndt <info@chrisarndt.de>
+# Copyright (C) 2020-2022 Christopher Arndt <info@chrisarndt.de>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -89,6 +89,16 @@ for pathdir in os.getenv("PATH", "/usr/local/bin:/usr/bin:/bin").split(os.pathse
         break
 
 
+# -------------------------------------------------------------------------------------------------
+# Custom exceptions
+
+
+class JackCaptureUnsupportedError(Exception):
+    """Raised when external jack_capture program version is not supported."""
+
+    pass
+
+
 # -------------------------------------------------------------------------------------------------
 # Utility functions
 
@@ -400,13 +410,25 @@ class QJackCaptureMainWindow(QDialog):
         self.fProcess.start(gJackCapturePath, ["-pf"])
         self.fProcess.waitForFinished()
 
+        if self.fProcess.exitCode() != 0:
+            raise JackCaptureUnsupportedError(
+                self.tr("Could not get list of supported output formats from jack_capture.")
+            )
+
         formats = []
 
-        for fmt in str(self.fProcess.readAllStandardOutput(), encoding="utf-8").split():
+        for fmt in str(self.fProcess.readAllStandardOutput(), encoding="utf-8").strip().split():
             fmt = fmt.strip()
             if fmt:
                 formats.append(fmt)
 
+        log.debug("File formats supported by jack_capture: %s", formats)
+
+        if not formats:
+            raise JackCaptureUnsupportedError(
+                self.tr("List of supported output formats reported by jack_capture is empty.")
+            )
+
         # Put all file formats in combo-box, select 'wav' option
         self.ui.cb_format.clear()
         for i, fmt in enumerate(sorted(formats)):
@@ -434,9 +456,13 @@ class QJackCaptureMainWindow(QDialog):
             self.inputs_model.clear()
 
         output_ports = list(self.fJackClient.get_output_ports())
-        self.output_ports = self.populatePortList(self.outputs_model, self.ui.tree_outputs, output_ports)
+        self.output_ports = self.populatePortList(
+            self.outputs_model, self.ui.tree_outputs, output_ports
+        )
         input_ports = list(self.fJackClient.get_input_ports())
-        self.input_ports = self.populatePortList(self.inputs_model, self.ui.tree_inputs, input_ports)
+        self.input_ports = self.populatePortList(
+            self.inputs_model, self.ui.tree_inputs, input_ports
+        )
 
         # Remove ports, which are no longer present, from recording sources
         all_ports = set((p.client, p.name) for p in output_ports)
@@ -466,7 +492,9 @@ class QJackCaptureMainWindow(QDialog):
 
         for client in humansorted(portsdict):
             clientitem = QStandardItem(client)
-            portsdict[client] = humansorted(portsdict[client], key=attrgetter("group", "order", "pretty_name", "name"))
+            portsdict[client] = humansorted(
+                portsdict[client], key=attrgetter("group", "order", "pretty_name", "name")
+            )
 
             for port in portsdict[client]:
                 portspec = (port.client, port.name)
@@ -1006,7 +1034,7 @@ def main(args=None):
         type=posnum,
         default=3.0,
         metavar="SECONDS",
-        help="Interval between attempts to connect to JACK server " " (default: %(default)s)",
+        help="Interval between attempts to connect to JACK server (default: %(default)s)",
     )
     ap.add_argument(
         "-m",
@@ -1039,6 +1067,7 @@ def main(args=None):
                 PROGRAM,
                 "JACK is not available in this system, cannot use this application.",
             ),
+            QMessageBox.Close,
         )
         return 1
 
@@ -1051,6 +1080,7 @@ def main(args=None):
                 "The 'jack_capture' application is not available.\n"
                 "Is not possible to render without it!",
             ),
+            QMessageBox.Close,
         )
         return 2
 
@@ -1073,11 +1103,25 @@ def main(args=None):
                 "See console log for more information.",
             )
             % exc,
+            QMessageBox.Close,
         )
         return 1
 
     # Show GUI
-    gui = QJackCaptureMainWindow(None, jack_client, cargs.client_name)
+    try:
+        gui = QJackCaptureMainWindow(None, jack_client, cargs.client_name)
+    except JackCaptureUnsupportedError as exc:
+        QMessageBox.critical(
+            None,
+            app.translate(PROGRAM, "Error"),
+            app.translate(
+                PROGRAM, "The 'jack_capture' application found is not compatible.\n\nReason: %s"
+            )
+            % exc,
+            QMessageBox.Close,
+        )
+        return 1
+
     gui.setWindowIcon(get_icon("media-record", 48))
     gui.show()
 
